==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.2/sql/autolimits_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists autolimits_au//
create trigger autolimits_au after update on autolimits
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID,
     userID, username, action, classes, server, section, teststep, details, unit, newvalues)
  select NEW.verfahrenID, NEW.accessID, 'autolimits', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v), showreg(NEW.section, NEW.section_v),
    showreg(NEW.teststep, NEW.teststep_v), showreg(NEW.details, NEW.details_v),
    showreg(NEW.einheit, NEW.einheit_v),
    concat('function=', g.code, '\nover=', NEW.anzmittel, '\nrelation=', NEW.vergleich,
           '\ninfolevel=', NEW.infowert, '\nwarnlevel=', NEW.warnwert, '\nerrorlevel=',
           NEW.errorwert, '\nexclude=', NEW.exclude, '\nnotifymode=', NEW.notifymode, '\nmessage=',
           quotenl(NEW.meldung), '\ndestination1=',
           notifdestname(NEW.meldungszielID), '\ndest1levels=',
           if(find_in_set('INFO', NEW.ziel1level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel1level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel1level), 'F', ''), '\ndestination2=',
           notifdestname(NEW.meldungsziel2ID), '\ndest2levels=',
           if(find_in_set('INFO', NEW.ziel2level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel2level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel2level), 'F', ''), '\nremark=',
           quotenl(NEW.bemerkungen), '\nactive=', NEW.aktiv)
  from groupfunctions as g
  where NEW.TS != OLD.TS and g.ID = NEW.groupfunctionsID;
end//


drop trigger if exists autolimits_ai//
create trigger autolimits_ai after insert on autolimits
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID,
     userID, username, action, classes, server, section, teststep, details, unit, newvalues)
  select NEW.verfahrenID, NEW.accessID, 'autolimits', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v), showreg(NEW.section, NEW.section_v),
    showreg(NEW.teststep, NEW.teststep_v), showreg(NEW.details, NEW.details_v),
    showreg(NEW.einheit, NEW.einheit_v),
    concat('function=', g.code, '\nover=', NEW.anzmittel, '\nrelation=', NEW.vergleich,
           '\ninfolevel=', NEW.infowert, '\nwarnlevel=', NEW.warnwert, '\nerrorlevel=',
           NEW.errorwert, '\nexclude=', NEW.exclude, '\nnotifymode=', NEW.notifymode, '\nmessage=',
           quotenl(NEW.meldung), '\ndestination1=',
           notifdestname(NEW.meldungszielID), '\ndest1levels=',
           if(find_in_set('INFO', NEW.ziel1level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel1level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel1level), 'F', ''), '\ndestination2=',
           notifdestname(NEW.meldungsziel2ID), '\ndest2levels=',
           if(find_in_set('INFO', NEW.ziel2level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel2level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel2level), 'F', ''), '\nremark=',
           quotenl(NEW.bemerkungen), '\nactive=', NEW.aktiv)
  from groupfunctions as g
  where g.ID = NEW.groupfunctionsID;
end//


drop trigger if exists autolimits_bd//
create trigger autolimits_bd before delete on autolimits
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     classes, server, section, teststep, details, unit, newvalues)
  values
    (OLD.verfahrenID, OLD.accessID, 'autolimits', OLD.ID,
     coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
     showreg(OLD.classes, OLD.classes_v), showreg(OLD.server, OLD.server_v), showreg(OLD.section, OLD.section_v),
     showreg(OLD.teststep, OLD.teststep_v), showreg(OLD.details, OLD.details_v),
     showreg(OLD.einheit, OLD.einheit_v),
     coalesce(if(OLD.bemerkungen = @limitsremark, '', concat('remark=', quotenl(@limitsremark))),''));
end//

delimiter ;

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/autolimits_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists autolimits_au//
create trigger autolimits_au after update on autolimits
  for each row
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID,
     userID, username, action, classes, server, section, teststep, details, unit, newvalues)
  select verfahrenID, accessID, 'autolimits', autolimits.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    showreg(classes, classes_v), showreg(server, server_v), showreg(section, section_v),
    showreg(teststep, teststep_v), showreg(details, details_v),
    showreg(einheit, einheit_v),
    concat('function=', g.code, '\nover=', anzmittel, '\nrelation=', vergleich,
           '\ninfolevel=', infowert, '\nwarnlevel=', warnwert, '\nerrorlevel=',
           errorwert, '\nexclude=', exclude, '\nnotifymode=', notifymode, '\nmessage=',
           REPLACE(REPLACE(meldung, '\\', '\\\\'), '\n', '\\n'), '\ndestination1=',
           notifdestname(meldungszielID), '\ndest1levels=',
           if(find_in_set('INFO', ziel1level), 'I', ''),
           if(find_in_set('WARN', ziel1level), 'W', ''),
           if(find_in_set('ERROR', ziel1level), 'F', ''), '\ndestination2=',
           notifdestname(meldungsziel2ID), '\ndest2levels=',
           if(find_in_set('INFO', ziel2level), 'I', ''),
           if(find_in_set('WARN', ziel2level), 'W', ''),
           if(find_in_set('ERROR', ziel2level), 'F', ''), '\nremark=',
           REPLACE(REPLACE(bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', aktiv)
  from autolimits
  join groupfunctions as g on g.ID = groupfunctionsID
  where autolimits.ID = NEW.ID and autolimits.TS = NEW.TS;
end//


drop trigger if exists autolimits_ai//
create trigger autolimits_ai after insert on autolimits
  for each row
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID,
     userID, username, action, classes, server, section, teststep, details, unit, newvalues)
  select NEW.verfahrenID, NEW.accessID, 'autolimits', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v), showreg(NEW.section, NEW.section_v),
    showreg(NEW.teststep, NEW.teststep_v), showreg(NEW.details, NEW.details_v),
    showreg(NEW.einheit, NEW.einheit_v),
    concat('function=', g.code, '\nover=', NEW.anzmittel, '\nrelation=', NEW.vergleich,
           '\ninfolevel=', NEW.infowert, '\nwarnlevel=', NEW.warnwert, '\nerrorlevel=',
           NEW.errorwert, '\nexclude=', NEW.exclude, '\nnotifymode=', NEW.notifymode, '\nmessage=',
           REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'), '\ndestination1=',
           notifdestname(NEW.meldungszielID), '\ndest1levels=',
           if(find_in_set('INFO', NEW.ziel1level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel1level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel1level), 'F', ''), '\ndestination2=',
           notifdestname(NEW.meldungsziel2ID), '\ndest2levels=',
           if(find_in_set('INFO', NEW.ziel2level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel2level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel2level), 'F', ''), '\nremark=',
           REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.aktiv)
  from groupfunctions as g
  where g.ID = NEW.groupfunctionsID;
end//


drop trigger if exists autolimits_bd//
create trigger autolimits_bd before delete on autolimits
  for each row
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     classes, server, section, teststep, details, unit, newvalues)
  values
    (OLD.verfahrenID, OLD.accessID, 'autolimits', OLD.ID,
     coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
     showreg(OLD.classes, OLD.classes_v), showreg(OLD.server, OLD.server_v), showreg(OLD.section, OLD.section_v),
     showreg(OLD.teststep, OLD.teststep_v), showreg(OLD.details, OLD.details_v),
     showreg(OLD.einheit, OLD.einheit_v),
     coalesce(if(OLD.bemerkungen = @limitsremark, '', concat('remark=', REPLACE(REPLACE(@limitsremark, '\\', '\\\\'), '\n', '\\n'))),''));
end//

delimiter ;
